powered by
caltheta calculates the angle of convergence (radians) for left or right eye to fixate at a designated fixation distance.
caltheta
caltheta(fixdist, pd = NULL, gender = NULL, eye = c("left", "right"))
A two element vector of fixation distance in mm in Cartesian coordinates.
A number of pupil distance in mm.
A string of either "male" or "female"
A string specifying either "left" or "right" eye.
The angle of convergence in radians that respective eye with a pupil distance of pd rolls to fixate at fixation distance of fixdist.
pd
fixdist
the value of either pd or gender has to be provided the unit of pd and fixdist must be the same and is default to mm.
# NOT RUN { caltheta(c(600, 0), pd=65, eye="left") caltheta(c(600, 0), gender="male", eye="left") # }
Run the code above in your browser using DataLab