Learn R Programming

binovisualfields (version 0.1.1)

get_inv_col: Color-codes dB values

Description

get_inv_col returns the color of a visual field location given its dB value, (e.g., white < 15dB, black > 15dB)

Usage

get_inv_col(db)

Arguments

db

A number of sensitivity threshold in dB

Value

either white or black color for a visual field location

Examples

Run this code
# NOT RUN {
get_inv_col(25)
# }

Run the code above in your browser using DataLab