powered by
get_inv_col returns the color of a visual field location given its dB value, (e.g., white < 15dB, black > 15dB)
get_inv_col
get_inv_col(db)
A number of sensitivity threshold in dB
either white or black color for a visual field location
# NOT RUN { get_inv_col(25) # }
Run the code above in your browser using DataLab